.. _swh-journal:

Software Heritage - Journal
===========================

Persistent logger of changes to the archive, with publish-subscribe support.


.. toctree::
   :maxdepth: 2

   journal-clients

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
